==> blancoNLpackGenerator-0.0.88a-src.zip: src/blanco/xliff/util/task/BlancoXliffUtilMergeTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoXliffUtilMerge]̃NX
 */
package blanco.xliff.util.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.xliff.util.task.valueobject.BlancoXliffUtilMergeProcessInput;

/**
 * Apache Ant^XN [BlancoXliffUtilMerge]̃NXB
 *
 * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.xliff.util.task]BlancoXliffUtilMergeBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blancoxliffutilmerge&quot; classname=&quot;blanco.xliff.util.task.BlancoXliffUtilMergeTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoXliffUtilMergeTask extends Task {
    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected BlancoXliffUtilMergeProcessInput fInput = new BlancoXliffUtilMergeProcessInput();

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldTargetdirProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldSourcedirProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldSourcefileProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldToolidProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldSettargetProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldSettargetoverwriteProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldSetalttransProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C()܂܂fBNgBɏ܂BύX  XLIFF ݂̂Ɏ{܂B<br>
     *
     * @param arg Zbgl
     */
    public void setTargetdir(final String arg) {
        fInput.setTargetdir(arg);
        fIsFieldTargetdirProcessed = true;
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C()܂܂fBNgBɏ܂BύX  XLIFF ݂̂Ɏ{܂B<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetdir() {
        return fInput.getTargetdir();
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)܂܂fBNgBӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcefileƔrpB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcedir(final String arg) {
        fInput.setSourcedir(arg);
        fIsFieldSourcedirProcessed = true;
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)܂܂fBNgBӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcefileƔrpB<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcedir() {
        return fInput.getSourcedir();
    }

    /**
     * Ant^XN[sourcefile]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)Bӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcedirƔrpB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcefile(final String arg) {
        fInput.setSourcefile(arg);
        fIsFieldSourcefileProcessed = true;
    }

    /**
     * Ant^XN[sourcefile]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)Bӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcedirƔrpB<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcefile() {
        return fInput.getSourcefile();
    }

    /**
     * Ant^XN[toolid]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * }[W{ۂɗp tool-idBnlpack  pleiades Ȃǂw肵܂Balt-trans ŗp܂B<br>
     *
     * @param arg Zbgl
     */
    public void setToolid(final String arg) {
        fInput.setToolid(arg);
        fIsFieldToolidProcessed = true;
    }

    /**
     * Ant^XN[toolid]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * }[W{ۂɗp tool-idBnlpack  pleiades Ȃǂw肵܂Balt-trans ŗp܂B<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getToolid() {
        return fInput.getToolid();
    }

    /**
     * Ant^XN[settarget]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 5<br>
     * trans-unit  target ɂāAlZbg邩ǂBȂA{I source 񂪈v邱ƂOƂȂ܂B<br>
     *
     * @param arg Zbgl
     */
    public void setSettarget(final boolean arg) {
        fInput.setSettarget(arg);
        fIsFieldSettargetProcessed = true;
    }

    /**
     * Ant^XN[settarget]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 5<br>
     * trans-unit  target ɂāAlZbg邩ǂBȂA{I source 񂪈v邱ƂOƂȂ܂B<br>
     * ftHgl[false]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getSettarget() {
        return fInput.getSettarget();
    }

    /**
     * Ant^XN[settargetoverwrite]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 6<br>
     * trans-unit  target ɂāA݂̗Lɂ炸lZbg邩ǂB|󕨂̗D揇ʂ݂ꍇ̃}[WɂĂ̂݃Zbg܂B<br>
     *
     * @param arg Zbgl
     */
    public void setSettargetoverwrite(final boolean arg) {
        fInput.setSettargetoverwrite(arg);
        fIsFieldSettargetoverwriteProcessed = true;
    }

    /**
     * Ant^XN[settargetoverwrite]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 6<br>
     * trans-unit  target ɂāA݂̗Lɂ炸lZbg邩ǂB|󕨂̗D揇ʂ݂ꍇ̃}[WɂĂ̂݃Zbg܂B<br>
     * ftHgl[false]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getSettargetoverwrite() {
        return fInput.getSettargetoverwrite();
    }

    /**
     * Ant^XN[setalttrans]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 7<br>
     * alt-trans Zbg邩ǂB<br>
     *
     * @param arg Zbgl
     */
    public void setSetalttrans(final boolean arg) {
        fInput.setSetalttrans(arg);
        fIsFieldSetalttransProcessed = true;
    }

    /**
     * Ant^XN[setalttrans]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 7<br>
     * alt-trans Zbg邩ǂB<br>
     * ftHgl[false]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getSetalttrans() {
        return fInput.getSetalttrans();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoXliffUtilMergeTask begin.");

        // ڔԍ[1]AAgr[g[targetdir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldTargetdirProcessed == false) {
            throw new BuildException("K{Agr[g[targetdir]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[4]AAgr[g[toolid]͕K{͂łB̓`FbNs܂B
        if (fIsFieldToolidProcessed == false) {
            throw new BuildException("K{Agr[g[toolid]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- targetdir:[" + getTargetdir() + "]");
            System.out.println("- sourcedir:[" + getSourcedir() + "]");
            System.out.println("- sourcefile:[" + getSourcefile() + "]");
            System.out.println("- toolid:[" + getToolid() + "]");
            System.out.println("- settarget:[" + getSettarget() + "]");
            System.out.println("- settargetoverwrite:[" + getSettargetoverwrite() + "]");
            System.out.println("- setalttrans:[" + getSetalttrans() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoXliffUtilMergeProcessC^tF[X blanco.xliff.util.taskpbP[W BlancoXliffUtilMergeProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoXliffUtilMergeProcess proc = new BlancoXliffUtilMergeProcessImpl();
            if (proc.execute(fInput) != BlancoXliffUtilMergeBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}

==> blancoNLpackGenerator-0.1.2-src.zip: src/blanco/xliff/util/task/BlancoXliffUtilMergeTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoXliffUtilMerge]̃NX
 */
package blanco.xliff.util.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.xliff.util.task.valueobject.BlancoXliffUtilMergeProcessInput;

/**
 * Apache Ant^XN [BlancoXliffUtilMerge]̃NXB
 *
 * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.xliff.util.task]BlancoXliffUtilMergeBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blancoxliffutilmerge&quot; classname=&quot;blanco.xliff.util.task.BlancoXliffUtilMergeTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoXliffUtilMergeTask extends Task {
    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected BlancoXliffUtilMergeProcessInput fInput = new BlancoXliffUtilMergeProcessInput();

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldTargetdirProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldSourcedirProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldSourcefileProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldToolidProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldSettargetProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldSettargetoverwriteProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldSetalttransProcessed = false;

    /**
     * [XLIFFΉc[] w肳ꂽfBNgԂ OASIS XLIFF t@C(*.xlf)}[W܂B̃^XN targetdir()DƂ}[W{܂Bsourcedir(E)݂̂ɑ݂trans-unit (Babel URI)͔j܂BNote͓]܂B
     */
    protected boolean fIsFieldCopyalttransProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C()܂܂fBNgBɏ܂BύX  XLIFF ݂̂Ɏ{܂B<br>
     *
     * @param arg Zbgl
     */
    public void setTargetdir(final String arg) {
        fInput.setTargetdir(arg);
        fIsFieldTargetdirProcessed = true;
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C()܂܂fBNgBɏ܂BύX  XLIFF ݂̂Ɏ{܂B<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetdir() {
        return fInput.getTargetdir();
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)܂܂fBNgBӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcefileƔrpB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcedir(final String arg) {
        fInput.setSourcedir(arg);
        fIsFieldSourcedirProcessed = true;
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)܂܂fBNgBӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcefileƔrpB<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcedir() {
        return fInput.getSourcedir();
    }

    /**
     * Ant^XN[sourcefile]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)Bӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcedirƔrpB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcefile(final String arg) {
        fInput.setSourcefile(arg);
        fIsFieldSourcefileProcessed = true;
    }

    /**
     * Ant^XN[sourcefile]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)Bӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcedirƔrpB<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcefile() {
        return fInput.getSourcefile();
    }

    /**
     * Ant^XN[toolid]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * }[W{ۂɗp tool-idBnlpack  pleiades Ȃǂw肵܂Balt-trans ŗp܂B<br>
     *
     * @param arg Zbgl
     */
    public void setToolid(final String arg) {
        fInput.setToolid(arg);
        fIsFieldToolidProcessed = true;
    }

    /**
     * Ant^XN[toolid]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * }[W{ۂɗp tool-idBnlpack  pleiades Ȃǂw肵܂Balt-trans ŗp܂B<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getToolid() {
        return fInput.getToolid();
    }

    /**
     * Ant^XN[settarget]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 5<br>
     * trans-unit  target ɂāAlZbg邩ǂBȂA{I source 񂪈v邱ƂOƂȂ܂B<br>
     *
     * @param arg Zbgl
     */
    public void setSettarget(final boolean arg) {
        fInput.setSettarget(arg);
        fIsFieldSettargetProcessed = true;
    }

    /**
     * Ant^XN[settarget]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 5<br>
     * trans-unit  target ɂāAlZbg邩ǂBȂA{I source 񂪈v邱ƂOƂȂ܂B<br>
     * ftHgl[false]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getSettarget() {
        return fInput.getSettarget();
    }

    /**
     * Ant^XN[settargetoverwrite]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 6<br>
     * trans-unit  target ɂāA݂̗Lɂ炸lZbg邩ǂB|󕨂̗D揇ʂ݂ꍇ̃}[WɂĂ̂݃Zbg܂B<br>
     *
     * @param arg Zbgl
     */
    public void setSettargetoverwrite(final boolean arg) {
        fInput.setSettargetoverwrite(arg);
        fIsFieldSettargetoverwriteProcessed = true;
    }

    /**
     * Ant^XN[settargetoverwrite]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 6<br>
     * trans-unit  target ɂāA݂̗Lɂ炸lZbg邩ǂB|󕨂̗D揇ʂ݂ꍇ̃}[WɂĂ̂݃Zbg܂B<br>
     * ftHgl[false]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getSettargetoverwrite() {
        return fInput.getSettargetoverwrite();
    }

    /**
     * Ant^XN[setalttrans]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 7<br>
     * Zbg target ̓e alt-trans ɃZbg邩ǂB<br>
     *
     * @param arg Zbgl
     */
    public void setSetalttrans(final boolean arg) {
        fInput.setSetalttrans(arg);
        fIsFieldSetalttransProcessed = true;
    }

    /**
     * Ant^XN[setalttrans]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 7<br>
     * Zbg target ̓e alt-trans ɃZbg邩ǂB<br>
     * ftHgl[false]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getSetalttrans() {
        return fInput.getSetalttrans();
    }

    /**
     * Ant^XN[copyalttrans]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 8<br>
     * ͌ alt-trans  o͐ alt-trans ɃZbg邩ǂB<br>
     *
     * @param arg Zbgl
     */
    public void setCopyalttrans(final boolean arg) {
        fInput.setCopyalttrans(arg);
        fIsFieldCopyalttransProcessed = true;
    }

    /**
     * Ant^XN[copyalttrans]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 8<br>
     * ͌ alt-trans  o͐ alt-trans ɃZbg邩ǂB<br>
     * ftHgl[false]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getCopyalttrans() {
        return fInput.getCopyalttrans();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoXliffUtilMergeTask begin.");

        // ڔԍ[1]AAgr[g[targetdir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldTargetdirProcessed == false) {
            throw new BuildException("K{Agr[g[targetdir]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[4]AAgr[g[toolid]͕K{͂łB̓`FbNs܂B
        if (fIsFieldToolidProcessed == false) {
            throw new BuildException("K{Agr[g[toolid]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- targetdir:[" + getTargetdir() + "]");
            System.out.println("- sourcedir:[" + getSourcedir() + "]");
            System.out.println("- sourcefile:[" + getSourcefile() + "]");
            System.out.println("- toolid:[" + getToolid() + "]");
            System.out.println("- settarget:[" + getSettarget() + "]");
            System.out.println("- settargetoverwrite:[" + getSettargetoverwrite() + "]");
            System.out.println("- setalttrans:[" + getSetalttrans() + "]");
            System.out.println("- copyalttrans:[" + getCopyalttrans() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoXliffUtilMergeProcessC^tF[X blanco.xliff.util.taskpbP[W BlancoXliffUtilMergeProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoXliffUtilMergeProcess proc = new BlancoXliffUtilMergeProcessImpl();
            if (proc.execute(fInput) != BlancoXliffUtilMergeBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}
